@@ -62,8 +62,8 @@ def create_all_metadata(
         This data is added by DMS if the source extra connection attribute is set.
 
     include_derived_columns (boolean):
-        If True, adds four columns: mojap_latest_record, mojap_start_datetime,
-        mojap_end_datetime, mojap_deleted_record.
+        If True, adds three columns: mojap_current_record, mojap_start_datetime,
+        mojap_end_datetime.
 
     include_objects (boolean):
         If True, will include metadata for DB_TYPE_OBJECT columns as array<character>.
@@ -136,8 +136,8 @@ def create_metadata_folder(
         This data is added by DMS if the source extra connection attribute is set.
 
     include_derived_columns (boolean):
-        If True, adds four columns: mojap_latest_record, mojap_start_datetime,
-        mojap_end_datetime, mojap_deleted_record.
+        If True, adds three columns: mojap_current_record, mojap_start_datetime,
+        mojap_end_datetime.
 
     include_objects (boolean):
         If True, will include metadata for DB_TYPE_OBJECT columns as array<character>.
@@ -173,7 +173,11 @@ def create_metadata_folder(
 
 
 def create_json_for_database(
-    description: str, name: str, bucket: str, base_folder: str, location="./meta_data",
+    description: str,
+    name: str,
+    bucket: str,
+    base_folder: str,
+    location="./meta_data",
 ):
     """Creates a database.json file suitable for reading with read_database_folder()
 
@@ -246,8 +250,8 @@ def create_json_for_tables(
         This data is added by DMS if the source extra connection attribute is set.
 
     include_derived_columns (boolean):
-        If True, adds four columns: mojap_latest_record, mojap_start_datetime,
-        mojap_end_datetime, mojap_deleted_record.
+        If True, adds three columns: mojap_current_record, mojap_start_datetime,
+        mojap_end_datetime.
 
     include_objects (boolean):
         If True, will include metadata for DB_TYPE_OBJECT columns as array<character>.
@@ -275,22 +279,18 @@ def create_json_for_tables(
             # fetchone() to see the first row of the query executed
             cursor.execute(f"SELECT * FROM {schema}.{table} WHERE ROWNUM <= 1")
             cursor.fetchone()
-            # For Delius purposes we only want tables with at least 1 row
+            # For Delius purposes we want all tables including those without rows
             # This might not be the case for all metadata
-            if cursor.rowcount > 0:
-                metadata = get_table_meta(
-                    cursor,
-                    table,
-                    not_nullable.get(table.lower(), []),
-                    include_op_column,
-                    include_timestamp_column,
-                    include_derived_columns,
-                    include_objects,
-                )
-                write_json(metadata, Path(location) / f"{table.lower()}.json")
-
-            else:
-                print(f"No rows in {table} from {schema}")
+            metadata = get_table_meta(
+                cursor,
+                table,
+                not_nullable.get(table.lower(), []),
+                include_op_column,
+                include_timestamp_column,
+                include_derived_columns,
+                include_objects,
+            )
+            write_json(metadata, Path(location) / f"{table.lower()}.json")
 
         except Exception as e:
             # Likely errors are that the table has been deleted, marked
@@ -343,8 +343,8 @@ def get_table_meta(
         This data is added by AWS DMS, when configured as an extra connection attribute.
 
     include_derived_columns (boolean):
-        If True, adds four columns: mojap_latest_record, mojap_start_datetime,
-        mojap_end_datetime, mojap_deleted_record.
+        If True, adds three columns: mojap_current_record, mojap_start_datetime,
+        mojap_end_datetime.
 
     include_objects (boolean):
         If True, will include metadata for DB_TYPE_OBJECT columns as array<character>.
@@ -433,7 +433,7 @@ def get_table_meta(
     ]
     derived_columns = [
         {
-            "name": "mojap_latest_record",
+            "name": "mojap_current_record",
             "type": "boolean",
             "description": "If the record is current",
             "nullable": False,
@@ -450,12 +450,6 @@ def get_table_meta(
             "description": "When the record ceased to be current",
             "nullable": False,
         },
-        {
-            "name": "mojap_deleted_record",
-            "type": "boolean",
-            "description": "If the record has been deleted",
-            "nullable": False,
-        },
     ]
 
     # Not yet used - retained from Oasys metadata functions in case it helps later
